@@ -5,7 +5,7 @@ use warnings;
 use 5.010;
 
 # ABSTRACT: Simple asynchronous FTP client and server
-our $VERSION = '0.09'; # VERSION
+our $VERSION = '0.10'; # VERSION
 
 
 1;
@@ -22,7 +22,7 @@ AnyEvent::FTP - Simple asynchronous FTP client and server
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 SYNOPSIS
 
@@ -74,6 +74,21 @@ It used to also be tested against the VMS ftp server, so it was verified to
 work with it, at least at one point. However, I no longer have access to that
 server.
 
+=head1 BUNDLED FILES
+
+This distribution comes bundled with C<ls> from the old
+L<Perl Power Tools|https://metacpan.org/release/ppt> project.
+This is only used on C<MSWin32> if this command is not found in
+the path, as it is frequently not available on that platform
+
+The Perl implementation of C<ls>
+was written by Mark Leighton Fisher of Thomson Consumer Electronics,
+I<fisherm@tce.com>.
+
+That program is free and open software. You may use, modify,
+distribute, and sell it program (and any modified variants) in any
+way you wish, provided you do not restrict others from doing the same.
+
 =head1 SEE ALSO
 
 =over 4
@@ -142,6 +157,8 @@ Ryo Okamoto
 
 Shlomi Fish
 
+José Joaquín Atria
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2013 by Graham Ollis.
