@@ -5,13 +5,14 @@ use warnings;
 use 5.010;
 use Moo;
 use File::chdir;
-use File::Spec;
+use File::Share qw( dist_file );
+use File::Which qw( which );
 use File::Temp qw( tempfile );
 
 extends 'AnyEvent::FTP::Server::Context::FS';
 
 # ABSTRACT: FTP Server client context class with full read/write access
-our $VERSION = '0.09'; # VERSION
+our $VERSION = '0.10'; # VERSION
 
 
 with 'AnyEvent::FTP::Server::Role::TransferPrep';
@@ -27,19 +28,19 @@ sub help_retr { 'RETR <sp> pathname' }
 sub cmd_retr
 {
   my($self, $con, $req) = @_;
-  
+
   my $fn = $req->args;
-  
+
   unless(defined $self->data)
   {
     $con->send_response(425 => 'Unable to build data connection');
     return;
   }
-  
+
   eval {
     use autodie;
     local $CWD = $self->cwd;
-    
+
     if(-f $fn)
     {
       # TODO: re-write so that this does not blocks
@@ -81,26 +82,26 @@ sub help_nlst { 'NLST [<sp> (pathname)]' }
 sub cmd_nlst
 {
   my($self, $con, $req) = @_;
-  
+
   my $dir = $req->args || '.';
-  
+
   unless(defined $self->data)
   {
     $con->send_response(425 => 'Unable to build data connection');
     return;
   }
-  
+
   eval {
     use autodie;
     local $CWD = $self->cwd;
-    
+
     $con->send_response(150 => "Opening ASCII mode data connection for file list");
     my $dh;
     opendir $dh, $dir;
-    my @list = 
-      map { $req->args ? join('/', $dir, $_) : $_ } 
-      sort 
-      grep !/^\.\.?$/, 
+    my @list =
+      map { $req->args ? join('/', $dir, $_) : $_ }
+      sort
+      grep !/^\.\.?$/,
       readdir $dh;
     closedir $dh;
     $self->data->push_write(join '', map { $_ . "\015\012" } @list);
@@ -125,24 +126,28 @@ sub help_list { 'LIST [<sp> pathname]' }
 sub cmd_list
 {
   my($self, $con, $req) = @_;
-  
+
   my $dir = $req->args || '.';
   $dir = '.' if $dir eq '-l';
-  
+
   unless(defined $self->data)
   {
     $con->send_response(425 => 'Unable to build data connection');
     return;
   }
-  
+
   eval {
     use autodie;
+
+    my @cmd = _shared_cmd('ls', '-l', $dir);
+    my $cmd = join ' ', @cmd;
+
     local $CWD = $self->cwd;
-    
+
     $con->send_response(150 => "Opening ASCII mode data connection for file list");
     my $dh;
     opendir $dh, $dir;
-    $self->data->push_write(join "\015\012", split /\n/, `ls -l $dir`);
+    $self->data->push_write(join "\015\012", split /\n/, `$cmd`);
     closedir $dh;
     $self->data->push_write("\015\012");
     $self->data->push_shutdown;
@@ -168,13 +173,13 @@ sub cmd_stor
   my($self, $con, $req) = @_;
 
   my $fn = $req->args;
-  
+
   unless(defined $self->data)
   {
     $con->send_response(425 => 'Unable to build data connection');
     return;
   }
-  
+
   eval {
     use autodie;
     local $CWD = $self->cwd;
@@ -218,13 +223,13 @@ sub cmd_appe
   my($self, $con, $req) = @_;
 
   my $fn = $req->args;
-  
+
   unless(defined $self->data)
   {
     $con->send_response(425 => 'Unable to build data connection');
     return;
   }
-  
+
   eval {
     use autodie;
     local $CWD = $self->cwd;
@@ -268,13 +273,13 @@ sub cmd_stou
   my($self, $con, $req) = @_;
 
   my $fn = $req->args;
-  
+
   unless(defined $self->data)
   {
     $con->send_response(425 => 'Unable to build data connection');
     return;
   }
-  
+
   eval {
     use autodie;
     local $CWD = $self->cwd;
@@ -320,6 +325,31 @@ sub cmd_stou
   };
 }
 
+{
+  state $always_use_bundled_cmd = $ENV{ANYEVENT_FTP_BUNDLED_CMD};
+  my %shared;
+  sub _shared_cmd
+  {
+    my ($cmd, @args) = @_;
+
+    unless (defined $shared{$cmd}) {
+      my $which = which $cmd;
+      if ($which && !$always_use_bundled_cmd) {
+        $shared{$cmd} = [ $which ];
+      }
+      else {
+        require AnyEvent::FTP; # dist_file needs this loaded so it can find it in %INC
+        $shared{$cmd} = [
+          $^X,  # use the same Perl
+          dist_file 'AnyEvent-FTP', 'ppt/' . $cmd . '.pl',
+        ];
+      }
+    }
+
+    return @{ $shared{$cmd} }, @args;
+  }
+}
+
 1;
 
 __END__
@@ -334,12 +364,12 @@ AnyEvent::FTP::Server::Context::FSRW - FTP Server client context class with full
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 SYNOPSIS
 
  use AnyEvent::FTP::Server;
- 
+
  my $server = AnyEvent::FTP::Server->new(
    default_context => 'AnyEvent::FTP::Server::Context::FSRW',
  );
@@ -396,6 +426,8 @@ Ryo Okamoto
 
 Shlomi Fish
 
+José Joaquín Atria
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2013 by Graham Ollis.
